@@ -730,9 +730,10 @@ class Model {
         });
         found = compact(found);
       } else {
-        found = this._schema.db[
-          this._schema.toInternalCollectionName(association.modelName)
-        ].find(foreignKeys);
+        found =
+          this._schema.db[
+            this._schema.toInternalCollectionName(association.modelName)
+          ].find(foreignKeys);
       }
 
       let foreignKeyLabel = association.isPolymorphic
@@ -751,9 +752,10 @@ class Model {
           this._schema.toInternalCollectionName(foreignKeys.type)
         ].find(foreignKeys.id);
       } else {
-        found = this._schema.db[
-          this._schema.toInternalCollectionName(association.modelName)
-        ].find(foreignKeys);
+        found =
+          this._schema.db[
+            this._schema.toInternalCollectionName(association.modelName)
+          ].find(foreignKeys);
       }
 
       let foreignKeyLabel = association.isPolymorphic
@@ -870,9 +872,10 @@ class Model {
           this._schema.toCollectionName(associateId.type)
         ].find(associateId.id);
       } else {
-        associate = this._schema[
-          this._schema.toCollectionName(association.modelName)
-        ].find(associateId);
+        associate =
+          this._schema[
+            this._schema.toCollectionName(association.modelName)
+          ].find(associateId);
       }
 
       if (associate.hasInverseFor(association)) {
@@ -1005,9 +1008,10 @@ class Model {
           this._schema.toInternalCollectionName(model.modelName)
         ].update(model.id, { [inverseFk]: newId });
       } else {
-        let inverseCollection = this._schema.db[
-          this._schema.toInternalCollectionName(model.modelName)
-        ];
+        let inverseCollection =
+          this._schema.db[
+            this._schema.toInternalCollectionName(model.modelName)
+          ];
         let currentIdsForInverse =
           inverseCollection.find(model.id)[inverse.getForeignKey()] || [];
         let newIdsForInverse = Object.assign([], currentIdsForInverse);
