@@ -265,9 +265,15 @@ export default class Schema {
 
     This will return `null` if the schema doesn't have any matching record.
 
+    A predicate function can also be used to find a match.
+
+    ```js
+    let longPost = blogPosts.findBy((post) => post.body.length > 1000);
+    ```
+
     @method findBy
     @param type
-    @param attributeName
+    @param attributesOrPredicate
     @public
    */
   findBy(type, query) {
