@@ -299,7 +299,7 @@ class Serializer {
       }
       ```
 
-      Setting `embed` to true will embed related records:
+      Setting `embed` to true will embed all related records:
 
       ```js
       Serializer.extend({
@@ -323,8 +323,11 @@ class Serializer {
         }
       }
       ```
+
+      You can also define `embed` as a function so it can be determined dynamically.
     */
     this.embed = this.embed || undefined; // this is just here so I can add the doc comment. Better way?
+    this.embedFn = isFunction(this.embed) ? this.embed : () => !!this.embed;
 
     /**
       Use this to define how your serializer handles serializing relationship keys. It can take one of three values:
@@ -473,11 +476,8 @@ class Serializer {
     didSerialize = {},
     lookupSerializer = false
   ) {
-    let hash, serializer;
-
-    if (!lookupSerializer) {
-      serializer = this; // this is used for embedded responses
-    }
+    let serializer = this;
+    let hash;
 
     // PolymorphicCollection lacks a modelName, but is dealt with in the map
     // by looking up the serializer on a per-model basis
@@ -508,25 +508,22 @@ class Serializer {
       });
     }
 
-    if (this.embed) {
-      return [hash, []];
-    } else {
-      let addToIncludes = uniqBy(
-        compact(
-          flatten(
-            serializer.getKeysForIncluded().map((key) => {
-              if (this.isCollection(resource)) {
-                return resource.models.map((m) => m[key]);
-              } else {
-                return resource[key];
-              }
-            })
-          )
-        ),
-        (m) => m.toString()
-      );
-      return [hash, addToIncludes];
-    }
+    let addToIncludes = uniqBy(
+      compact(
+        flatten(
+          serializer.getKeysForIncluded().map((key) => {
+            if (this.isCollection(resource)) {
+              return resource.models.map((m) => m[key]);
+            } else {
+              return resource[key];
+            }
+          })
+        )
+      ),
+      (m) => m.toString()
+    );
+
+    return [hash, addToIncludes];
   }
 
   /*
@@ -692,7 +689,7 @@ class Serializer {
       newDidSerialize[model.modelName] = newDidSerialize[model.modelName] || {};
       newDidSerialize[model.modelName][model.id] = true;
 
-      this.getKeysForIncluded().forEach((key) => {
+      this.getKeysForEmbedded().forEach((key) => {
         let associatedResource = model[key];
         if (
           associatedResource &&
@@ -716,11 +713,9 @@ class Serializer {
           }
         }
       });
-
-      return attrs;
-    } else {
-      return this._maybeAddAssociationIds(model, attrs);
     }
+
+    return this._maybeAddAssociationIds(model, attrs);
   }
 
   /**
@@ -1114,12 +1109,20 @@ class Serializer {
     return this.registry.serializerFor(type);
   }
 
-  getKeysForIncluded() {
+  getAssociationKeys() {
     return isFunction(this.include)
       ? this.include(this.request, this.primaryResource)
       : this.include;
   }
 
+  getKeysForEmbedded() {
+    return this.getAssociationKeys().filter((k) => this.embedFn(k));
+  }
+
+  getKeysForIncluded() {
+    return this.getAssociationKeys().filter((k) => !this.embedFn(k));
+  }
+
   /**
     A reference to the schema instance.
 
