@@ -228,7 +228,7 @@ class JSONAPISerializer extends Serializer {
     let relationshipPaths;
 
     if (this.hasQueryParamIncludes()) {
-      relationshipPaths = this.request.queryParams.include.split(",");
+      relationshipPaths = this.getQueryParamIncludes();
     } else {
       let serializer = this.serializerFor(resource.modelName);
       relationshipPaths = serializer.getKeysForIncluded();
@@ -438,10 +438,8 @@ class JSONAPISerializer extends Serializer {
   _addPrimaryModelToRequestedIncludesGraph(graph, model) {
     if (this.hasQueryParamIncludes()) {
       let graphKey = this._graphKeyForModel(model);
-      let queryParamIncludes = this.getQueryParamIncludes();
 
-      queryParamIncludes
-        .split(",")
+      this.getQueryParamIncludes()
         .filter((item) => !!item.trim())
         .forEach((includesPath) => {
           // includesPath is post.comments, for example
@@ -556,7 +554,13 @@ class JSONAPISerializer extends Serializer {
   }
 
   getQueryParamIncludes() {
-    return get(this, "request.queryParams.include");
+    let includes = get(this, "request.queryParams.include");
+
+    if (includes && !Array.isArray(includes)) {
+      includes = includes.split(",");
+    }
+
+    return includes;
   }
 
   hasQueryParamIncludes() {
