@@ -1,5 +1,7 @@
 import DbCollection from "miragejs/db-collection";
 import { Server } from "miragejs/server";
+import { Registry } from "miragejs";
+import { ModelDefinition } from "miragejs/-types";
 
 const server: Server = new Server();
 
@@ -37,3 +39,16 @@ myDb.users.remove({ name: "Zelda" }); // $ExpectType void
 myDb.users.update({ name: "Ganon" }); // $ExpectType any
 myDb.users.update(1, { name: "Young Link" }); // $ExpectType any
 myDb.users.update({ name: "Link" }, { name: "Epona" }); // $ExpectType any
+
+type TestModels = {
+  movie: ModelDefinition<Movie>;
+};
+
+type TestRegistry = Registry<TestModels, {}>;
+
+const testServer = new Server<TestRegistry>();
+
+// There's a problem with dtslint that we can't specify different results for different
+// versions of typescript.  The result here will be either `ModelInstance<{ title: string; }> | null`
+// or `Instantiate<TestRegistry, "movie"> | null`, depending on TS version.
+testServer.schema.findBy("movie", (instance) => instance.title.length > 0);
